// Kyle VanDaele
// ball.cpp

#include "ball.h"

// default constructor
Ball::Ball() : Entity()
{
	spriteData.width = ballNS::WIDTH;		// size of ball
	spriteData.height = ballNS::HEIGHT;
	spriteData.x = ballNS::X;				//location on screen
	spriteData.y = ballNS::Y;
	spriteData.rect.bottom = ballNS::HEIGHT;
	spriteData.rect.right = ballNS::WIDTH;
	velocity.x = 0;
	velocity.y = 250;
	frameDelay = ballNS::ANIMATION_DELAY;
	startFrame = ballNS::START_FRAME;		// first frame of ball animation
	endFrame = ballNS::END_FRAME;			// last frame of ball animation
	currentFrame = startFrame;
	radius = ballNS::WIDTH/2.0;
	collisionType = entityNS::CIRCLE;
	mass = ballNS::MASS;
	BallColor = 'r';
}

// update
// called once per frame
// frameTime is used to regulate the speed of movement and animation
void Ball::update(float frameTime)
{
	Entity::update(frameTime);
	
	spriteData.y += frameTime * velocity.y;		// move ball along Y

	if(velocity.y > 0 && velocity.y > 500)
		velocity.y = 500;
	if(velocity.y > 0 && velocity.y < 200)
		velocity.y = 200;
	if(velocity.y < 0 && velocity.y < -500)
		velocity.y = -500;
	if(velocity.y < 0 && velocity.y > -200)
		velocity.y = -200;

	if(input->isKeyDown(BALL_RIGHT_KEY))							// if right arrow is pressed
		spriteData.x = spriteData.x + frameTime * ballNS::SPEED;	// move ball right
	if(input->isKeyDown(BALL_LEFT_KEY))								// if left arrow is pressed
		spriteData.x = spriteData.x - frameTime * ballNS::SPEED;	// move ball left

	if(input->isKeyDown(BALL_UP_KEY) && (velocity.y > -500 && velocity.y < 500))	// if up arrow is pressed
		if(velocity.y > 0)															// change the velocity to
			velocity.y += frameTime * ballNS::SPEED;								// make the ball go faster
		else if(velocity.y < 0)
			velocity.y -= frameTime * ballNS::SPEED;

	if(input->isKeyDown(BALL_DOWN_KEY) && (velocity.y > 200 || velocity.y < -200))	// if the down arrow is pressed
		if(velocity.y < 0)															// change the velocity to
			velocity.y += frameTime * ballNS::SPEED;								// make the ball go slower
		else if(velocity.y > 0)
			velocity.y -= frameTime * ballNS::SPEED;

	// bounce off walls
	if(spriteData.x > GAME_WIDTH-ballNS::WIDTH)		// if hit right screen edge
	{
		spriteData.x = GAME_WIDTH-ballNS::WIDTH;	// position at right screen edge
		velocity.x = -velocity.x;					// reverse x direction
	} else if(spriteData.x < 0)						// else if hit left screen edge
	{
		spriteData.x = 0;							// position at left screen edge
		velocity.x = -velocity.x;					// reverse x direction
	}

	if(spriteData.y > 816-ballNS::HEIGHT)	// if hit bottom screen edge
	{
		spriteData.y = 816-ballNS::HEIGHT;	// position at bottom screen edge
		velocity.y = -velocity.y;					// reverse y direction

		// play audio cue
		audio->playCue(WALL_HIT);
	} else if(spriteData.y < 0)						// else if hit top screen edge
	{
		spriteData.y = 0;							// position at top screen edge
		velocity.y = -velocity.y;					// reverse y direction

		// play audio cue
		audio->playCue(WALL_HIT);
	}
}

void Ball::SetLocation(int xloc, int yloc)
{
	xlocation = xloc;
	ylocation = yloc;
}


void Ball::ResetLoc()
{
	setX(xlocation);
	setY(ylocation);
	velocity.y = 250;
	velocity.x = 0;
}

void Ball::setBallColor(char color)
{
	BallColor = color;

	switch(color)
	{
	case 'r':
		setColorFilter(graphicsNS::RED);
		break;
	case 'g':
		setColorFilter(graphicsNS::LIME);
		break;
	case 'b':
		setColorFilter(graphicsNS::BLUE);
		break;
	}
}