// Kyle VanDaele
// getmoney.cpp

#include "getmoney.h"

//=============================================================================
// Constructor
//=============================================================================
GetMoney::GetMoney()
{
	dxFontScore = new TextDX();		// directx Font
	dxFontScoreTitle = new TextDX();
	dxFontTimer = new TextDX();
	dxFontTimerTitle = new TextDX();
	scorecounter = 0;
	level = 1;
	menuOn = true;
	lm = 0;
	levelMenuOn = false;
	gameCompleteOn = false;
	gameOverOn = false;
	timercounter = 0;
	livescounter = 5;
}

//=============================================================================
// Destructor
//=============================================================================
GetMoney::~GetMoney()
{
    releaseAll();           // call onLostDevice() for every graphics item
}

//=============================================================================
// Initializes the game
// Throws GameError on error
//=============================================================================
void GetMoney::initialize(HWND hwnd)
{
    Game::initialize(hwnd); // throws GameError

	// initialize DirectX fonts
	// 48 pixel high Arial
	if(!dxFontScore->initialize(graphics, 48, true, false, "Arial"))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing DirectX font"));

	if(!dxFontScoreTitle->initialize(graphics, 48, true, false, "Arial"))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing DirectX font"));

	if(!dxFontTimer->initialize(graphics, 48, true, false, "Arial"))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing DirectX font"));

	if(!dxFontTimerTitle->initialize(graphics, 48, true, false, "Arial"))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing DirectX font"));

	// menu texture
    if (!menuTexture.initialize(graphics,MENU_IMAGE))
        throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing menu texture"));

	// in between level menu texture
	if(!levelmenuTexture.initialize(graphics, LEVEL_MENU_IMAGE))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing level menu texture"));

	// game complete texture
	if(!gamecompleteTexture.initialize(graphics, GAME_COMPLETE_IMAGE))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing game complete texture"));

	// game over texture
	if(!gameoverTexture.initialize(graphics, GAME_OVER_IMAGE))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing game over texture"));

    // background texture
    if (!bgTexture.initialize(graphics,BG_IMAGE))
        throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing background texture"));

    // ball texture
    if (!ballTexture.initialize(graphics,BALL_IMAGE))
        throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing ball texture"));

	// block texture
	if (!blockTexture.initialize(graphics,BLOCK_IMAGE))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing block texture"));

	// menu
	if(!menu.initialize(graphics, 0, 0, 0, &menuTexture))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing menu"));

	// level menu
	if(!levelmenu.initialize(graphics, GAME_WIDTH, GAME_HEIGHT, 2, &levelmenuTexture))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing level menu"));
	levelmenu.setCurrentFrame(0);
	levelmenu.setVisible(false);

	// Game complete image
	if(!gamecomplete.initialize(graphics, 0, 0, 0, &gamecompleteTexture))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing game complete image"));

	// game over image
	if(!gameover.initialize(graphics, 0, 0, 0, &gameoverTexture))
		throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing game over image"));

	// background
    if (!bg.initialize(graphics,0,0,0,&bgTexture))
        throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing background"));

    // ball
    if (!ball.initialize(this, ballNS::WIDTH, ballNS::HEIGHT, ballNS::TEXTURE_COLS, &ballTexture))
        throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing ball"));

	
	for(int x = 0; x <= 4; x++)
	{
		// red blocks
		for(int y = 0; y <= 19; y++)
		{
			if(!Rblock[x][y].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
				throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing a red block"));
			Rblock[x][y].setVisible(false);
			Rblock[x][y].setActive(false);
		}

		// green blocks
		for(int y = 0; y <= 19; y++)
		{
			if(!Gblock[x][y].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
				throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing a green block"));
			Gblock[x][y].setVisible(false);
			Gblock[x][y].setActive(false);
		}

		// blue blocks
		for(int y = 0; y <= 19; y++)
		{
			if(!Bblock[x][y].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
				throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing a blue block"));
			Bblock[x][y].setVisible(false);
			Bblock[x][y].setActive(false);
		}

		// money blocks
		for(int y = 0; y <= 19; y++)
		{
			if(!moneyblock[x][y].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
				throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing money block"));
			moneyblock[x][y].setCurrentFrame(1);
			moneyblock[x][y].setVisible(false);
			moneyblock[x][y].setActive(false);
		}

		// blue paint block
		if(!Bpaintblock[x].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
			throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing blue paint block"));
		Bpaintblock[x].setCurrentFrame(2);
		Bpaintblock[x].setVisible(false);
		Bpaintblock[x].setActive(false);

		// green paint block
		if(!Gpaintblock[x].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
			throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing green paint block"));
		Gpaintblock[x].setCurrentFrame(2);
		Gpaintblock[x].setVisible(false);
		Gpaintblock[x].setActive(false);

		// red paint block
		if(!Rpaintblock[x].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
			throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing red paint block"));
		Rpaintblock[x].setCurrentFrame(2);
		Rpaintblock[x].setVisible(false);
		Rpaintblock[x].setActive(false);

		// death block
		for(int y = 0; y <= 19; y++)
		{
			if(!deathblock[x][y].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
				throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing death block"));
			deathblock[x][y].setCurrentFrame(3);
			deathblock[x][y].setVisible(false);
			deathblock[x][y].setActive(false);
		}

		// wall block
		for(int y = 0; y <= 19; y++)
		{
			if(!wallblock[x][y].initialize(this, blockNS::WIDTH, blockNS::HEIGHT, blockNS::TEXTURE_COLS, &blockTexture))
				throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing wall block"));
			wallblock[x][y].setVisible(false);
			wallblock[x][y].setActive(false);
		}
	}

	// lives
	for(int x = 0; x <= 4; x++)
	{
		if(!lives[x].initialize(graphics, ballNS::WIDTH, ballNS::HEIGHT, 0, &ballTexture))
			throw(GameError(gameErrorNS::FATAL_ERROR, "Error initializing lives"));
		lives[x].setY(825);
	}
	lives[0].setX(660);
	lives[1].setX(740);
	lives[2].setX(820);
	lives[3].setX(900);
	lives[4].setX(980);

	setLevel(level);

    return;
}

//=============================================================================
// Update all game items
//=============================================================================
void GetMoney::update()
{
	if(menuOn)									// if game is started
	{
		if(input->anyKeyPressed())				// press a key to get rid of start menu and start the game
		{
			menuOn = false;
			input->clearAll();
		}
	}
	else if(level <= 5 && levelMenuOn)			// if a level is complete
	{
		levelmenu.setVisible(true);				// show level text

		if(input->anyKeyPressed())				// if user presses a key
		{
			levelmenu.setVisible(false);		// get rid of the text
			levelMenuOn = false;
			input->clearAll();
			lm++;								// set level text frame to next level
			levelmenu.setCurrentFrame(lm);
		}

	}
	else if(gameCompleteOn)						// if game is complete
	{
		if(input->anyKeyPressed())				// if user presses any key it closes the game
			PostQuitMessage(0);
	}
	else if(gameOverOn)
	{
		if(input->anyKeyPressed())
			PostQuitMessage(0);
	}

	else
	{
		//if(input->isKeyDown(VK_SPACE))		// used for testing purposes
		//	moneyblockcount = 0;

		ball.update(frameTime);
		timercounter -= frameTime;				// update timer

		if(timercounter <= 0)
		{
			ball.ResetLoc();
			ball.setBallColor('r');
			timercounter = 300;
			
			// play death audio cue
			audio->playCue(DEATHBLOCK_HIT);

			for(int i = 0; i <= 4; i++)
				lives[i].setColorFilter(graphicsNS::RED);

			lives[livescounter - 1].setVisible(false);
			livescounter--;

			if(livescounter == 0)
				gameOverOn = true;
		}

		for(int i = 0; i >= 4; i++)				// update lives images to match color of ball
			lives[i].update(frameTime);

		if(moneyblockcount == 0)						// if no more money blocks, level is complete
		{
			Rpaintblock[level-1].setActive(false);
			Rpaintblock[level-1].setVisible(false);		// remove paint blocks
			Gpaintblock[level-1].setActive(false);
			Gpaintblock[level-1].setVisible(false);
			Bpaintblock[level-1].setActive(false);
			Bpaintblock[level-1].setVisible(false);

			for(int x = 0; x <= 19; x++)				// remove death blocks
			{
				deathblock[level-1][x].setVisible(false);
				deathblock[level-1][x].setActive(false);
				wallblock[level-1][x].setVisible(false);
				wallblock[level-1][x].setActive(false);
			}

			scorecounter += timercounter;				// add time left to score

			levelMenuOn = true;							// turn on level menu text

			level++;			// increase level counter
			setLevel(level);	// create next level
		}
	}
}

//=============================================================================
// Artificial Intelligence
//=============================================================================
void GetMoney::ai()
{}

//=============================================================================
// Handle collisions
//=============================================================================
void GetMoney::collisions()
{
	VECTOR2 collisionvector;

	for(int p = 0; p <= 4; p++)
	{
		// collision between ball and red block
		for(int x = 0; x <= 19; x++)
		{
			if(ball.collidesWith(Rblock[p][x], collisionvector))
			{
				// bounce off block
				ball.bounce(collisionvector, Rblock[p][x]);
		
				if(ball.getBallColor() == 'r')
				{
					// make block disappear
					Rblock[p][x].setVisible(false);
					Rblock[p][x].setActive(false);
				
					// decrease block count
					blockcount--;

					// increase score counter
					scorecounter += 10;

					// play audio cue
					audio->playCue(BLOCK_HIT);
				}
				else
				{
					// play audio cue
					audio->playCue(WALL_HIT);
				}
			}
		}

		// collision between ball and green block
		for(int x = 0; x <= 19; x++)
		{
			if(ball.collidesWith(Gblock[p][x], collisionvector))
			{
				// bounce off block
				ball.bounce(collisionvector, Gblock[p][x]);
					
				if(ball.getBallColor() == 'g')
				{
					// make block disappear
					Gblock[p][x].setVisible(false);
					Gblock[p][x].setActive(false);
				
					// decrease block count
					blockcount--;

					// increase score counter
					scorecounter += 10;

					// play audio cue
					audio->playCue(BLOCK_HIT);
				}
				else
				{
					// play audio cue
					audio->playCue(WALL_HIT);
				}
			}
		}


		// collision between ball and blue block
		for(int x = 0; x <= 19; x++)
		{
			if(ball.collidesWith(Bblock[p][x], collisionvector))
			{
				// bounce off block
				ball.bounce(collisionvector, Bblock[p][x]);
					
				if(ball.getBallColor() == 'b')
				{
					// make block disappear
					Bblock[p][x].setVisible(false);
					Bblock[p][x].setActive(false);
				
					// decrease block count
					blockcount--;

					// increase score counter
					scorecounter += 10;

					// play audio cue
					audio->playCue(BLOCK_HIT);
				}
				else
				{
					// play audio cue
					audio->playCue(WALL_HIT);
				}
			}
		}

		// collision between ball and money block
		for(int x = 0; x <= 19; x++)
		{
			if(ball.collidesWith(moneyblock[p][x], collisionvector))
			{
				// bounce off money block
				ball.bounce(collisionvector, moneyblock[p][x]);
					
				if(blockcount == 0)
				{
					// make block disappear
					moneyblock[p][x].setVisible(false);
					moneyblock[p][x].setActive(false);
					moneyblockcount--;

					// increase score counter
					scorecounter += 100;

					// play audio cue
					audio->playCue(MONEYBLOCK_HIT);
				}
				else
				{
					// play audio cue
					audio->playCue(WALL_HIT);
				}
			}
		}
	}

	for(int x = 0; x <= 4; x++)
	{
		// collision between ball and blue paint block
		if(ball.collidesWith(Bpaintblock[x], collisionvector))
		{
			ball.bounce(collisionvector, Bpaintblock[x]);
			
			if(ball.getBallColor() != 'b')
			{
				// play audio cue
				audio->playCue(PAINTBLOCK_HIT);
				
				ball.setBallColor('b');
				
				for(int i = 0; i <= 4; i++)
					lives[i].setColorFilter(graphicsNS::BLUE);
			}
			else
			{
				// play audio cue
				audio->playCue(WALL_HIT);
			}
		}

		// collision between ball and green paint block
		if(ball.collidesWith(Gpaintblock[x], collisionvector))
		{
			ball.bounce(collisionvector, Gpaintblock[x]);

			if(ball.getBallColor() != 'g')
			{
				// play audio cue
				audio->playCue(PAINTBLOCK_HIT);
				
				ball.setBallColor('g');
				
				for(int i = 0; i <= 4; i++)
					lives[i].setColorFilter(graphicsNS::LIME);
			}
			else
			{
				// play audio cue
				audio->playCue(WALL_HIT);
			}
		}

		// collision between ball and red paint block
		if(ball.collidesWith(Rpaintblock[x], collisionvector))
		{
			ball.bounce(collisionvector, Rpaintblock[x]);

			if(ball.getBallColor() != 'r')
			{
				// play audio cue
				audio->playCue(PAINTBLOCK_HIT);
				
				ball.setBallColor('r');
				
				for(int i = 0; i <= 4; i++)
					lives[i].setColorFilter(graphicsNS::RED);
			}
			else
			{
				// play audio cue
				audio->playCue(WALL_HIT);
			}
		}
	}

	
	for(int p = 0; p <= 4; p++)
	{
		// collision between ball and death block
		for(int x = 0; x <= 19; x++)
		{
			
			if(ball.collidesWith(deathblock[p][x], collisionvector))
			{
				ball.ResetLoc();				// reset ball location
				ball.setBallColor('r');

				lives[livescounter - 1].setVisible(false);	// decrease lives by 1
				livescounter--;

				// play audio cue
				audio->playCue(DEATHBLOCK_HIT);

				if(livescounter == 0)					// if no more lives, game over!
					gameOverOn = true;

				for(int i = 0; i <= 4; i++)				// set lives color
					lives[i].setColorFilter(graphicsNS::RED);
			}
		}

		// collision between ball and wall block
		for(int x = 0; x <= 19; x++)
		{
			if(ball.collidesWith(wallblock[p][x], collisionvector))
			{
				ball.bounce(collisionvector, wallblock[p][x]);

				// play audio cue
				audio->playCue(WALL_HIT);
			}
		}
	}
}

//=============================================================================
// Render game items
//=============================================================================
void GetMoney::render()
{
    graphics->spriteBegin();                // begin drawing sprites

    bg.draw();                          // add the background image to the scene
	
	for(int p = 0; p <= 4; p++)
	{
		// add red block images to the scene
		for(int i = 0; i <= 19; i++)
			Rblock[p][i].draw(graphicsNS::RED);

		// add green block images to the scene
		for(int i = 0; i <= 19; i++)
			Gblock[p][i].draw(graphicsNS::LIME);

		// add blue blocks to the scene
		for(int i = 0; i <= 19; i++)
			Bblock[p][i].draw(graphicsNS::BLUE);

		// add money blocks to the game
		for(int i = 0; i <= 19; i++)
			moneyblock[p][i].draw();
		
		// add death blocks to the scene
		for(int i = 0; i <= 19; i++)
			deathblock[p][i].draw();

		// add wall blocks to the scene
		for(int i = 0; i <= 19; i++)
			wallblock[p][i].draw();
	}

	for(int i = 0; i <= 4; i++)
	{
		Bpaintblock[i].draw(graphicsNS::BLUE);
		Gpaintblock[i].draw(graphicsNS::LIME);
		Rpaintblock[i].draw(graphicsNS::RED);
	}
	
	for(int i = 0; i <= 4; i++)
		lives[i].draw(graphicsNS::FILTER);

	ball.draw(graphicsNS::FILTER);			// add the ball image to the scene

	// display score
	dxFontScoreTitle->setFontColor(graphicsNS::YELLOW);
	dxFontScoreTitle->print("Score:", 30, 820);

	dxFontScore->setFontColor(graphicsNS::YELLOW);
	_snprintf_s(scorebuffer, SCORE_BUF_SIZE, "%d", (int)scorecounter);
	dxFontScore->print(scorebuffer, 160, 820);

	// display timer
	dxFontTimerTitle->setFontColor(graphicsNS::YELLOW);
	dxFontTimerTitle->print("Time:", 340, 820);

	dxFontTimer->setFontColor(graphicsNS::YELLOW);
	_snprintf_s(timerbuffer, TIMER_BUF_SIZE, "%d", (int)timercounter);
	dxFontTimer->print(timerbuffer, 460, 820);

	if(menuOn)
		menu.draw();

	levelmenu.draw();
	
	if(gameCompleteOn)
		gamecomplete.draw();

	if(gameOverOn)
		gameover.draw();

    graphics->spriteEnd();                  // end drawing sprites
}

//=============================================================================
// The graphics device was lost.
// Release all reserved video memory so graphics device may be reset.
//=============================================================================
void GetMoney::releaseAll()
{
	dxFontScore->onLostDevice();
	dxFontScoreTitle->onLostDevice();
	menuTexture.onLostDevice();
	levelmenuTexture.onLostDevice();
    ballTexture.onLostDevice();
	blockTexture.onLostDevice();
    bgTexture.onLostDevice();

    Game::releaseAll();
    return;
}

//=============================================================================
// The grahics device has been reset.
// Recreate all surfaces.
//=============================================================================
void GetMoney::resetAll()
{
	dxFontScore->onResetDevice();
	dxFontScoreTitle->onResetDevice();
	menuTexture.onResetDevice();
	levelmenuTexture.onResetDevice();
    ballTexture.onResetDevice();
	blockTexture.onResetDevice();
    bgTexture.onResetDevice();

    Game::resetAll();
    return;
}

 //=============================================================================
// Build the level.
//=============================================================================
void GetMoney::setLevel(int level)
{
	switch(level)
	{
	case 1:
		ball.SetLocation(GAME_WIDTH/4, GAME_WIDTH/4);
		ball.ResetLoc();						// start ball in top left screen
		ball.setVelocity(VECTOR2(ballNS::SPEED, -ballNS::SPEED));	// VECTOR2(X, Y)
		ball.setBallColor('r');					// set ball color to red

		for(int i = 0; i <= 4; i++)				// set lives color
			lives[i].setColorFilter(graphicsNS::RED);

		Rblock[0][0].setXY(5, 8);		// left of center
		Rblock[0][1].setXY(7, 8);		// place block right of center
		Rblock[0][2].setXY(6, 7);		// place block above center
		Rblock[0][3].setXY(6, 9);		// place block below center
		Rblock[0][4].setXY(1, 0);		// set red blocks to surround
		Rblock[0][5].setXY(0, 1);    // blue paint block

		Gblock[0][0].setXY(4, 8);		// two places left of center
		Gblock[0][1].setXY(5, 7);		// up and diagonal left of center
		Gblock[0][2].setXY(6, 6);		// two places above center
		Gblock[0][3].setXY(7, 7);		// up and diagonal right of center
		Gblock[0][4].setXY(8, 8);		// two right of center
		Gblock[0][5].setXY(7, 9);		// down and diagonal right of center
		Gblock[0][6].setXY(6, 10);		// two places below center
		Gblock[0][7].setXY(5, 9);		// down and diagonal left of center
		Gblock[0][8].setXY(11, 0);					// set green blocks to surround
		Gblock[0][9].setXY(12, 1);

		Bblock[0][0].setXY(3, 8);		// three places left of center
		Bblock[0][1].setXY(4, 7);		// diag up and left
		Bblock[0][2].setXY(5, 6);		// diag up and left
		Bblock[0][3].setXY(6, 5);		// three space up from center
		Bblock[0][4].setXY(7, 6);		// diag up and right
		Bblock[0][5].setXY(8, 7);		// diag up and right
		Bblock[0][6].setXY(9, 8);		// three spaces right of center
		Bblock[0][7].setXY(8, 9);		// diag down and right
		Bblock[0][8].setXY(7, 10);		// diag down and right
		Bblock[0][9].setXY(6, 11);		// three spaces down from center
		Bblock[0][10].setXY(5, 10);		// diag down and left
		Bblock[0][11].setXY(4, 9);		// diag down and left
		Bblock[0][12].setXY(1, 16);		// set blue blocks to surround		
		Bblock[0][13].setXY(0, 15);		// green paint block

		moneyblock[0][0].setXY(6, 8);	// set money block location
			
		Bpaintblock[0].setXY(0, 0);									// set paint block locations
		Gpaintblock[0].setXY(0, 16);
		Rpaintblock[0].setXY(12, 0);

		deathblock[0][0].setXY(12, 16);		// set death block locations
		deathblock[0][1].setXY(12, 15);
		deathblock[0][2].setXY(11, 16);

		blockcount = 30;
		moneyblockcount = 1;
		timercounter = 300;
		break;

	case 2:
		ball.SetLocation(GAME_WIDTH/4, GAME_HEIGHT/2);
		ball.ResetLoc();						// start ball in top left screen
		ball.setVelocity(VECTOR2(ballNS::SPEED, -ballNS::SPEED));	// VECTOR2(X, Y)
		ball.setBallColor('r');					// set ball color to red

		for(int i = 0; i <= 4; i++)				// set lives color
			lives[i].setColorFilter(graphicsNS::RED);

		moneyblock[1][0].setXY(3, 3);	// left eye
		moneyblock[1][1].setXY(9, 3);	// right eye
		moneyblock[1][2].setXY(6, 8);	// nose
		moneyblock[1][3].setXY(3, 11);	// money blocks
		moneyblock[1][4].setXY(4, 12);	// 3 through 91
		moneyblock[1][5].setXY(5, 12);	// form a mouth
		moneyblock[1][6].setXY(6, 12);
		moneyblock[1][7].setXY(7, 12);
		moneyblock[1][8].setXY(8, 12);
		moneyblock[1][9].setXY(9, 11);

		Rblock[1][0].setXY(2, 2);	// upper left of left eye
		Rblock[1][1].setXY(3, 2);	// above left eye
		Rblock[1][2].setXY(4, 2);	// upper right of left eye
		Rblock[1][3].setXY(4, 3);	// right of left eye
		Rblock[1][4].setXY(4, 4);	// lower right of left eye
		Rblock[1][5].setXY(3, 4);	// below left eye
		Rblock[1][6].setXY(2, 4);	// lower left/left eye
		Rblock[1][7].setXY(2, 3);	// left of left eye

		Rblock[1][8].setXY(8, 2);	// upper left/right eye
		Rblock[1][9].setXY(9, 2);	// above right eye
		Rblock[1][10].setXY(10, 2);	// upper right/right eye
		Rblock[1][11].setXY(10, 3);	// right of right eye
		Rblock[1][12].setXY(10, 4);	// lower right/right eye
		Rblock[1][13].setXY(9, 4);	// below right eye
		Rblock[1][14].setXY(8, 4);	// lower left/right eye
		Rblock[1][15].setXY(8, 3);	// left of right eye

		Bblock[1][0].setXY(3, 10);	// blue and green
		Bblock[1][1].setXY(4, 11);	// blocks go
		Gblock[1][0].setXY(5, 11);	// around the mouth
		Bblock[1][2].setXY(6, 11);	// in a fancy pattern
		Gblock[1][1].setXY(7, 11);
		Bblock[1][3].setXY(8, 11);
		Bblock[1][4].setXY(9, 10);
		Gblock[1][2].setXY(10, 11);
		Gblock[1][3].setXY(9, 12);
		Bblock[1][5].setXY(9, 13);
		Gblock[1][4].setXY(8, 13);
		Bblock[1][6].setXY(7, 13);
		Gblock[1][5].setXY(6, 13);
		Bblock[1][7].setXY(5, 13);
		Gblock[1][6].setXY(4, 13);
		Bblock[1][8].setXY(3, 13);
		Gblock[1][7].setXY(3, 12);
		Gblock[1][8].setXY(2, 11);

		Gpaintblock[1].setXY(5, 8);	// paint blocks form
		Rpaintblock[1].setXY(6, 7);	// around nose
		Bpaintblock[1].setXY(7, 8);

		deathblock[1][0].setXY(0, 0);	// death blocks go in the corners
		deathblock[1][1].setXY(1, 0);
		deathblock[1][2].setXY(11, 0);
		deathblock[1][3].setXY(12, 0);
		deathblock[1][4].setXY(0, 16);
		deathblock[1][5].setXY(1, 16);
		deathblock[1][6].setXY(11, 16);
		deathblock[1][7].setXY(12, 16);

		moneyblockcount = 10;
		blockcount = 34;
		timercounter = 300;
		break;

	case 3:
		ball.SetLocation(GAME_WIDTH/3, GAME_HEIGHT/4);
		ball.ResetLoc();						// start ball in top left screen
		ball.setVelocity(VECTOR2(ballNS::SPEED, -ballNS::SPEED));	// VECTOR2(X, Y)
		ball.setBallColor('r');					// set ball color to red

		for(int i = 0; i <= 4; i++)				// set lives color
			lives[i].setColorFilter(graphicsNS::RED);

		moneyblock[2][0].setXY(1, 6);		// money blocks
		moneyblock[2][1].setXY(1, 7);		// filling in
		moneyblock[2][2].setXY(1, 9);		// the empty
		moneyblock[2][3].setXY(1, 10);		// spaces in
		moneyblock[2][4].setXY(4, 7);	// the letters
		moneyblock[2][5].setXY(4, 9);
		moneyblock[2][6].setXY(6, 6);
		moneyblock[2][7].setXY(6, 7);
		moneyblock[2][8].setXY(6, 8);
		moneyblock[2][9].setXY(6, 9);
		moneyblock[2][10].setXY(8, 6);
		moneyblock[2][11].setXY(8, 7);
		moneyblock[2][12].setXY(8, 8);
		moneyblock[2][13].setXY(8, 9);
		moneyblock[2][14].setXY(10, 7);
		moneyblock[2][15].setXY(10, 8);
		moneyblock[2][16].setXY(10, 9);
		moneyblock[2][17].setXY(12, 9);

		Rblock[2][0].setXY(0, 6);		// red blocks forming
		Rblock[2][1].setXY(0, 7);		// a giant H
		Rblock[2][2].setXY(0, 8);
		Rblock[2][3].setXY(0, 9);
		Rblock[2][4].setXY(0, 10);
		Rblock[2][5].setXY(1, 8);
		Rblock[2][6].setXY(2, 6);
		Rblock[2][7].setXY(2, 7);
		Rblock[2][8].setXY(2, 8);
		Rblock[2][9].setXY(2, 9);
		Rblock[2][10].setXY(2, 10);

		Bblock[2][0].setXY(3, 6);	// blue blocks
		Bblock[2][1].setXY(3, 7);	// forming the
		Bblock[2][2].setXY(3, 8);	// letter E
		Bblock[2][3].setXY(3, 9);
		Bblock[2][4].setXY(3, 10);
		Bblock[2][5].setXY(4, 6);
		Bblock[2][6].setXY(4, 8);
		Bblock[2][7].setXY(4, 10);

		Gblock[2][0].setXY(5, 6);	// green blocks
		Gblock[2][1].setXY(5, 7);	// forming the
		Gblock[2][2].setXY(5, 8);	// letter L
		Gblock[2][3].setXY(5, 9);
		Gblock[2][4].setXY(5, 10);
		Gblock[2][5].setXY(6, 10);

		Rblock[2][11].setXY(7, 6);	// red blocks
		Rblock[2][12].setXY(7, 7);	// forming the
		Rblock[2][13].setXY(7, 8);	// letter L
		Rblock[2][14].setXY(7, 9);
		Rblock[2][15].setXY(7, 10);
		Rblock[2][16].setXY(8, 10);

		Bblock[2][8].setXY(9, 6);	// blue blocks
		Bblock[2][9].setXY(9, 7);	// forming the
		Bblock[2][10].setXY(9, 8);	// letter O
		Bblock[2][11].setXY(9, 9);
		Bblock[2][12].setXY(9, 10);
		Bblock[2][13].setXY(10, 6);
		Bblock[2][14].setXY(10, 10);
		Bblock[2][15].setXY(11, 6);
		Bblock[2][16].setXY(11, 7);
		Bblock[2][17].setXY(11, 8);
		Bblock[2][18].setXY(11, 9);
		Bblock[2][19].setXY(11, 10);

		Gblock[2][6].setXY(12, 7);	// green blocks
		Gblock[2][7].setXY(12, 8);	// forming a
		Gblock[2][8].setXY(12, 10);	// exclamation point

		Gpaintblock[2].setXY(12, 6);
		Rpaintblock[2].setXY(6, 16);					// set paint blocks
		Bpaintblock[2].setXY(6, 0);

		wallblock[2][0].setXY(0, 0);						// set wall blocks
		wallblock[2][1].setXY(2, 0);
		wallblock[2][2].setXY(4, 0);
		wallblock[2][3].setXY(8, 0);
		wallblock[2][4].setXY(10, 0);
		wallblock[2][5].setXY(12, 0);
		wallblock[2][6].setXY(0, 16);
		wallblock[2][7].setXY(2, 16);
		wallblock[2][8].setXY(4, 16);
		wallblock[2][9].setXY(8, 16);
		wallblock[2][10].setXY(10, 16);
		wallblock[2][11].setXY(12, 16);
		wallblock[2][12].setXY(5, 0);	// replaced deathblock
		wallblock[2][13].setXY(7, 0);	// replaced deathblock
		wallblock[2][14].setXY(5, 16);	// replaced deathblock
		wallblock[2][15].setXY(7, 16);	// replaced deathblock

		deathblock[2][0].setXY(1, 0);			// set death blocks
		deathblock[2][1].setXY(3, 0);
		//deathblock[2][2].setXY(5, 0);
		//deathblock[2][3].setXY(7, 0);
		deathblock[2][4].setXY(9, 0);
		deathblock[2][5].setXY(11, 0);
		deathblock[2][6].setXY(1, 16);
		deathblock[2][7].setXY(3, 16);
		//deathblock[2][8].setXY(5, 16);
		//deathblock[2][9].setXY(7, 16);
		deathblock[2][10].setXY(9, 16);
		deathblock[2][11].setXY(11, 16);

		moneyblockcount = 18;
		blockcount = 46;
		timercounter = 300;
		break;

	case 4:
		ball.SetLocation(GAME_WIDTH/4, GAME_HEIGHT/4 - 10);
		ball.ResetLoc();						// start ball in top left screen
		ball.setVelocity(VECTOR2(ballNS::SPEED, -ballNS::SPEED));	// VECTOR2(X, Y)
		ball.setBallColor('r');					// set ball color to green

		for(int i = 0; i <= 4; i++)				// set lives color
			lives[i].setColorFilter(graphicsNS::RED);

		moneyblock[3][0].setXY(4, 5);	// set money blocks
		moneyblock[3][1].setXY(5, 5);
		moneyblock[3][2].setXY(4, 6);
		moneyblock[3][3].setXY(5, 6);
		moneyblock[3][4].setXY(7, 5);
		moneyblock[3][5].setXY(8, 5);
		moneyblock[3][6].setXY(7, 6);
		moneyblock[3][7].setXY(8, 6);
		moneyblock[3][8].setXY(4, 8);
		moneyblock[3][9].setXY(6, 8);
		moneyblock[3][10].setXY(8, 8);
		moneyblock[3][11].setXY(4, 10);
		moneyblock[3][12].setXY(5, 10);
		moneyblock[3][13].setXY(4, 11);
		moneyblock[3][14].setXY(5, 11);
		moneyblock[3][15].setXY(7, 10);
		moneyblock[3][16].setXY(8, 10);
		moneyblock[3][17].setXY(7, 11);
		moneyblock[3][18].setXY(8, 11);

		Bblock[3][0].setXY(4, 7);	// set blue blocks
		Bblock[3][1].setXY(3, 6);
		Bblock[3][2].setXY(3, 5);
		Bblock[3][3].setXY(4, 4);
		Bblock[3][4].setXY(5, 4);
		Bblock[3][5].setXY(6, 5);
		Bblock[3][6].setXY(6, 6);
		Bblock[3][7].setXY(7, 4);
		Bblock[3][8].setXY(8, 4);
		Bblock[3][9].setXY(9, 5);
		Bblock[3][10].setXY(9, 6);
		Bblock[3][11].setXY(8, 7);

		Gblock[3][0].setXY(2, 8);	// set green blocks
		Gblock[3][1].setXY(3, 7);
		Gblock[3][2].setXY(3, 9);
		Gblock[3][3].setXY(5, 7);
		Gblock[3][4].setXY(6, 7);
		Gblock[3][5].setXY(7, 7);
		Gblock[3][6].setXY(7, 8);
		Gblock[3][7].setXY(7, 9);
		Gblock[3][8].setXY(6, 9);
		Gblock[3][9].setXY(5, 9);
		Gblock[3][10].setXY(5, 8);
		Gblock[3][11].setXY(9, 7);
		Gblock[3][12].setXY(9, 9);
		Gblock[3][13].setXY(10, 8);

		Rblock[3][0].setXY(4, 9);	// set red blocks
		Rblock[3][1].setXY(3, 10);
		Rblock[3][2].setXY(3, 11);
		Rblock[3][3].setXY(4, 12);
		Rblock[3][4].setXY(5, 12);
		Rblock[3][5].setXY(6, 10);
		Rblock[3][6].setXY(6, 11);
		Rblock[3][7].setXY(7, 12);
		Rblock[3][8].setXY(8, 12);
		Rblock[3][9].setXY(9, 10);
		Rblock[3][10].setXY(9, 11);
		Rblock[3][11].setXY(8, 9);

		Bpaintblock[3].setXY(3, 8);	// set paint blocks
		Gpaintblock[3].setXY(6, 12);
		Rpaintblock[3].setXY(9, 8);

		wallblock[3][0].setXY(2, 0);	// set wall blocks
		wallblock[3][1].setXY(3, 0);
		wallblock[3][2].setXY(4, 0);
		wallblock[3][3].setXY(5, 0);
		wallblock[3][4].setXY(7, 0);
		wallblock[3][5].setXY(8, 0);
		wallblock[3][6].setXY(9, 0);
		wallblock[3][7].setXY(10, 0);
		wallblock[3][8].setXY(2, 16);
		wallblock[3][9].setXY(3, 16);
		wallblock[3][10].setXY(4, 16);
		wallblock[3][11].setXY(5, 16);
		wallblock[3][12].setXY(7, 16);
		wallblock[3][13].setXY(8, 16);
		wallblock[3][14].setXY(9, 16);
		wallblock[3][15].setXY(10, 16);

		deathblock[3][0].setXY(0, 0);				// set death blocks
		deathblock[3][1].setXY(1, 0);
		deathblock[3][2].setXY(6, 0);
		deathblock[3][3].setXY(11, 0);
		deathblock[3][4].setXY(12, 0);
		deathblock[3][5].setXY(0, 16);
		deathblock[3][6].setXY(1, 16);
		deathblock[3][7].setXY(6, 16);
		deathblock[3][8].setXY(11, 16);
		deathblock[3][9].setXY(12, 16);

		moneyblockcount = 19;
		blockcount = 38;
		timercounter = 300;
		break;

	case 5:
		ball.SetLocation(GAME_WIDTH/4, GAME_HEIGHT/6);
		ball.ResetLoc();						// start ball in top left screen
		ball.setVelocity(VECTOR2(ballNS::SPEED, -ballNS::SPEED));	// VECTOR2(X, Y)
		ball.setBallColor('r');					// set ball color to green

		for(int i = 0; i <= 4; i++)				// set lives color
			lives[i].setColorFilter(graphicsNS::RED);

		moneyblock[4][0].setXY(2, 5);	// set money block locations
		moneyblock[4][1].setXY(3, 5);
		moneyblock[4][2].setXY(4, 5);
		moneyblock[4][3].setXY(2, 6);
		moneyblock[4][4].setXY(3, 6);
		moneyblock[4][5].setXY(4, 6);
		moneyblock[4][6].setXY(8, 5);
		moneyblock[4][7].setXY(9, 5);
		moneyblock[4][8].setXY(10, 5);
		moneyblock[4][9].setXY(8, 6);
		moneyblock[4][10].setXY(9, 6);
		moneyblock[4][11].setXY(10, 6);
		moneyblock[4][12].setXY(5, 9);
		moneyblock[4][13].setXY(6, 9);
		moneyblock[4][14].setXY(7, 9);
		moneyblock[4][15].setXY(5, 10);
		moneyblock[4][16].setXY(6, 10);
		moneyblock[4][17].setXY(7, 10);

		Gblock[4][0].setXY(0, 1);		// set green blocks to cover red paint block
		Gblock[4][1].setXY(1, 1);
		Gblock[4][2].setXY(2, 1);

		Rblock[4][0].setXY(10, 1);	// set red block to cover
		Rblock[4][1].setXY(11, 1);	// blue paint block
		Rblock[4][2].setXY(12, 1);

		Bblock[4][0].setXY(5, 15);	// set blue blocks
		Bblock[4][1].setXY(6, 15);	// to cover green paint block
		Bblock[4][2].setXY(7, 15);

		Rblock[4][3].setXY(1, 5);
		Rblock[4][4].setXY(2, 4);
		Rblock[4][5].setXY(3, 4);
		Rblock[4][6].setXY(4, 4);
		Rblock[4][7].setXY(5, 5);
		Bblock[4][3].setXY(1, 6);
		Bblock[4][4].setXY(2, 7);
		Bblock[4][5].setXY(3, 7);
		Bblock[4][6].setXY(4, 7);
		Bblock[4][7].setXY(5, 6);

		Bblock[4][8].setXY(7, 5);
		Bblock[4][9].setXY(8, 4);
		Bblock[4][10].setXY(9, 4);
		Bblock[4][11].setXY(10, 4);
		Bblock[4][12].setXY(11, 5);
		Gblock[4][3].setXY(7, 6);
		Gblock[4][4].setXY(8, 7);
		Gblock[4][5].setXY(9, 7);
		Gblock[4][6].setXY(10, 7);
		Gblock[4][7].setXY(11, 6);

		Rblock[4][8].setXY(4, 9);
		Rblock[4][9].setXY(5, 8);
		Rblock[4][10].setXY(6, 8);
		Rblock[4][11].setXY(7, 8);
		Rblock[4][12].setXY(8, 9);
		Gblock[4][8].setXY(4, 10);
		Gblock[4][9].setXY(5, 11);
		Gblock[4][10].setXY(6, 11);
		Gblock[4][11].setXY(7, 11);
		Gblock[4][12].setXY(8, 10);

		Rpaintblock[4].setXY(1, 0);
		Bpaintblock[4].setXY(11, 0);
		Gpaintblock[4].setXY(6, 16);

		wallblock[4][0].setXY(3, 0);
		wallblock[4][1].setXY(4, 0);
		wallblock[4][2].setXY(8, 0);
		wallblock[4][3].setXY(9, 0);
		wallblock[4][4].setXY(3, 16);
		wallblock[4][5].setXY(4, 16);
		wallblock[4][6].setXY(8, 16);
		wallblock[4][7].setXY(9, 16);

		deathblock[4][0].setXY(0, 0);
		deathblock[4][1].setXY(2, 0);
		deathblock[4][2].setXY(5, 0);
		deathblock[4][3].setXY(6, 0);
		deathblock[4][4].setXY(7, 0);
		deathblock[4][5].setXY(10, 0);
		deathblock[4][6].setXY(12, 0);
		deathblock[4][7].setXY(0, 16);
		deathblock[4][8].setXY(1, 16);
		deathblock[4][9].setXY(2, 16);
		deathblock[4][10].setXY(5, 16);
		deathblock[4][11].setXY(7, 16);
		deathblock[4][12].setXY(10, 16);
		deathblock[4][13].setXY(11, 16);
		deathblock[4][14].setXY(12, 16);

		moneyblockcount = 18;
		blockcount = 39;
		timercounter = 300;
		break;

	case 6:
		gameCompleteOn = true;
	}
}